import typer
import random

app = typer.Typer()


@app.callback()
def callback():
    """
    Awesome CLI user manager.
    """


@app.command()
def create(
    username: str = typer.Argument(
        ...,
        help="The name of user to create."
    )
):
    """
    Create a new user with USERNAME.
    """
    typer.echo(f"Creating user: {username}")


@app.command()
def delete(
    username: str = typer.Argument(
        ...,
        help="The name of user to delete."
    ),
    force: bool = typer.Option(
        ...,
        help="Force deletion without confirmation.",
        prompt="Are you sure?"
    )
):
    """
    Delete an existing user with USERNAME.

    If --force is not used, confirmation is required.
    """
    if force:
        typer.echo(f"Deleted user: {username}")
    else:
        typer.echo("Cancelled!")


@app.command()
def delete_all(
    force: bool = typer.Option(
        ...,
        help="Force deletion without confirmation.",
        prompt="Are you sure?"
    )
):
    """
    Delete all users in the database.

    If --force is not used, confirmation is required.
    """
    if force:
        typer.echo(f"Deleted all users.")
    else:
        typer.echo("Cancelled!")


def get_name():
    return random.choice(['Deadpool', 'Rick', 'Morty', 'Hiro'])


@app.command()
def init():
    """
    Initialize the user database.
    """
    typer.echo(f"Initializing user database as {get_name()}.")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['odc_typer_test']

package_data = \
{'': ['*']}

install_requires = \
['typer>=0.3.2,<0.4.0']

entry_points = \
{'console_scripts': ['odc-typer-test = odc_typer_test.main:app']}

setup_kwargs = {
    'name': 'odc-typer-test',
    'version': '0.1.0',
    'description': 'This is my package that tests out Typer.',
    'long_description': "# Typer Test\n\nI'm testing [Typer](/typer.tiangolo.com) here. What do you think?\n",
    'author': 'one-data-cookie',
    'author_email': 'kolacek.m@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
